expdeg: expdeg

View source: R/compareMetrics.R

expdegR Documentation

expdeg

Description

Calculate the expectation of degree distribution of network

Usage

expdeg(x)

Arguments

x

adjacency matrix

Details

Given a network in adjacency matrix form, this calculates the expected degree statistic using igraph degree distribution function.

Value

scaler

Author(s)

Abhirup

Examples

expdeg(beach[[1]][, ])

dnr documentation built on March 10, 2026, 9:06 a.m.