View source: R/compareMetrics.R
| expdeg | R Documentation |
Calculate the expectation of degree distribution of network
expdeg(x)
x |
adjacency matrix |
Given a network in adjacency matrix form, this calculates the expected degree statistic using igraph degree distribution function.
scaler
Abhirup
expdeg(beach[[1]][, ])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.